@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based objectqueue package
 
-$Id: interfaces.py 49723 2008-01-24 23:28:18Z cray $
+$Id: interfaces.py 49787 2008-01-29 22:36:59Z cray $
 """
-__author__  = "Yegor Shershnev, 2008"
+__author__  = "Yegor Shershnev & Elena Antusheva, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49723 $"
+__version__ = "$Revision: 49787 $"
  
 from zope.interface import Interface
 
@@ -17,23 +17,20 @@ from zope.app.container.constraints import ContainerTypesConstraint
 from zope.schema.vocabulary import SimpleVocabulary
 from zope.app.container.interfaces import IReadContainer
 
-class IObjectQueueHandler(Interface) :
+class IObjectQueueHandle(Interface) :
     
-    def itemAdd(ob) :
+    def handleAdded(ob) :
         """ Add object into queue
         """
 
-    def itemRemove(ob) :
+    def handleRemoved(ob) :
         """ Remove object from queue
         """
 
-    def itemModify(ob) :
+    def handleModified(ob) :
         """ Modufy object in queue
         """
 
-
-
-
 class IObjectQueueDataAdd(Interface) :
 
     maxlen = Int(
@@ -46,7 +43,7 @@ class IObjectQueueDataAdd(Interface) :
         title=u'Style',
         description=u"Style of queue",
         vocabulary = SimpleVocabulary.fromValues([u"fifo", u"lifo"]),
-        default=u"fifo",
+        default=u"lifo",
         required=True,
         )
     
@@ -56,10 +53,27 @@ class IObjectQueueDataAdd(Interface) :
         title=u'Order',
         description=u"Order",
         vocabulary = SimpleVocabulary.fromValues([u"straight", u"reverse"]),
-        default=u"straight",
+        default=u"reverse",
         required=True,
         )
 
+    use = Bool(
+        title=u'Queue is on',
+        description=u'Queue used to store changed items',
+        default=True
+        )
+        
+    islast = Bool(
+        title=u'Queue is last',
+        description=u'Treatment will be stop on this queue by the up way',
+        default=False
+        )
+        
+    usemodify = Bool(
+        title=u'Handle modify event',
+        description=u'Modify event on object will be handled by queue',
+        default=True
+        )            
 
 class IObjectQueueData(IObjectQueueDataAdd) :
     
@@ -71,10 +85,47 @@ class IObjectQueueData(IObjectQueueDataAdd) :
         )
 
 
-class IObjectQueue(IObjectQueueHandler, IObjectQueueData, IReadContainer):
+
+class IObjectQueueAvailable(Interface) :
+    pass
+    
+class IObjectQueueAnnotable(IObjectQueueAvailable) :
+    pass
+        
+class IObjectQueueUtilitable(IObjectQueueAvailable) :
+    pass
+            
+class IObjectQueue(IObjectQueueHandle, IObjectQueueData, IReadContainer, IObjectQueueAnnotable):
     pass
 
+
+class IObjectQueueAnnotation(IObjectQueue) :
+    pass
+    
+class IObjectQueueUtility(IObjectQueue) :
+    pass
+    
+class IObjectQueueAll(Interface) :
+    """ Enumerator for all ObjectQueue Utilities """
+
+    def next() :
+        pass 
+
+    def __iter__() :
+        pass
+
+class IObjectQueueUtilities(Interface) :
+    """ Enumerator for all ObjectQueue Utilities """
+
+    def next() :
+        pass 
+
+    def __iter__() :
+        pass
+
+
 class IObjectQueueAble(Interface) :
-    """ Interface of objects that can be queued
-    """
+    """ Interface of objects that can be queue"""
+ 
+objectqueuekey="ng.app.objectqueue.objectqueue.ObjectQueue"
 
