@@ -2,11 +2,11 @@
 #######################################################################
 """ObjectQueue class for the Zope 3 based objectqueue package
 
-$Id: objectqueue.py 49723 2008-01-24 23:28:18Z cray $
+$Id: objectqueue.py 49787 2008-01-29 22:36:59Z cray $
 """
 __author__  = "Yegor Shershnev, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49723 $"
+__version__ = "$Revision: 49787 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
@@ -15,21 +15,29 @@ from interfaces import IObjectQueue, IObjectQueueData
 from persistent.list import PersistentList
 from zope.app.zapi import getUtility
 from zope.app.intid.interfaces import IIntIds
+from zope.app.container.contained import Contained
+from zope.app.container.interfaces import IContained
 
-class ObjectQueue(Persistent) :
+class ObjectQueue(Persistent,Contained) :
     """ ObjectQueue class represent queue of last modified objects
     """
 
-    implements(IObjectQueueData, IObjectQueue)
+    implements(IObjectQueue,IContained)
 
-    _maxlen = 5
+    _maxlen = 10
     
-    style = u"lifo"
+    style = u"fifo"
     
-    order = u"straight"
+    order = u"reverse"
     
     length = 0
 
+    use = True
+    
+    islast = False
+    
+    usemodify = True
+
     def __init__(self, *kv, **args) :
         super(ObjectQueue, self).__init__(self, *kv, **args)
         self.queue = PersistentList()
@@ -39,12 +47,8 @@ class ObjectQueue(Persistent) :
         """
         if key not in self.queue:
             raise KeyError
-        ## Надо убедиться в правильности исправления
-        ## TODO: Контекст зачем убрал?
-        ## Убрал потому что так работает, а с контексом он утилиту не находил
-        #return getUtility(IIntIds, context=self).getObject(key)
-        ### Прими решение что делать с этим. У меня с контексом не работает
-        return getUtility(IIntIds).getObject(key)
+
+        return getUtility(IIntIds,context=self).getObject(int(key))
 
     def __len__(self) :
         return len(self.queue)
@@ -92,11 +96,11 @@ class ObjectQueue(Persistent) :
         """
         return [ y for x,y in self.items()]
     
-    def itemAdd(self, ob) :
+    def handleAdded(self, ob) :
         """ Add a key of object into queue
         """        
         try :
-            uid = getUtility(IIntIds, context=ob).getId(ob)
+            uid = str(getUtility(IIntIds, context=ob).getId(ob))
         except (KeyError), msg :
             print "Can't add",ob,"because of", msg
         else :
@@ -104,40 +108,38 @@ class ObjectQueue(Persistent) :
             style = self.style
             maxlen = self.maxlen
             
-            if style == u"lifo" and order == u"straight" :
+            if style == u"fifo" and order == u"straight" :
                 self.queue.insert(0, uid)
-                if len(self) > maxlen :
+                if len(self) >= maxlen :
                     self.queue.pop()
-            elif style == u"lifo" and order == u"reverse" :
-                self.queue.append(uid)
-                if len(self) > maxlen :
-                    self.queue.remove(self.queue[0])
-            elif style == u"fifo" and order == u"straight":
-                if len(self) > maxlen :
-                    self.queue.pop()
-                self.queue.append(uid)
             elif style == u"fifo" and order == u"reverse" :
-                if len(self) > maxlen :
+                self.queue.append(uid)
+                if len(self) >= maxlen :
+                    self.queue.remove(self.queue[0])
+            elif style == u"lifo" and order == u"straight":
+                if len(self) >= maxlen :
+                    self.queue.pop()
+                self.queue.append(uid)
+            elif style == u"lifo" and order == u"reverse" :
+                if len(self) >= maxlen :
                     self.queue.remove(self.queue[0])
                 self.queue.insert(0, uid)
                 
-            print "\n\nAdd", self.keys()
-
-    def itemRemove(self, ob) :
+    def handleRemoved(self, ob) :
         """ Remove object from queue
         """
         try :
-            uid = getUtility(IIntIds, context=ob).getId(ob)
+            uid = str(getUtility(IIntIds, context=ob).getId(ob))
         except (ValueError,KeyError), msg :
             print "Can't remove",ob,"because of",msg
         else :
             if uid not in self.keys():
                 return
             self.queue.remove(uid)
-            print "\n\nRemove:", self.keys()
         
-    def itemModify(self, ob) :
+    def handleModified(self, ob) :
         """ Modufy object in queue
         """
-        self.itemRemove(ob)
-        self.itemAdd(ob)
+        if self.usemodify: 
+            self.handleRemoved(ob)
+            self.handleAdded(ob)
